@@ -2,13 +2,13 @@ var _pro_s_h_a_d_e__maths_8hpp =
 [
     [ "ProSHADE_rotFun_sphere", "class_pro_s_h_a_d_e__internal__spheres_1_1_pro_s_h_a_d_e__rot_fun__sphere.html", "class_pro_s_h_a_d_e__internal__spheres_1_1_pro_s_h_a_d_e__rot_fun__sphere" ],
     [ "BicubicInterpolator", "class_pro_s_h_a_d_e__internal__maths_1_1_bicubic_interpolator.html", "class_pro_s_h_a_d_e__internal__maths_1_1_bicubic_interpolator" ],
-    [ "advanceGLPolyValue", "_pro_s_h_a_d_e__maths_8hpp.html#a4f2619c7f3b8d628af9cb356778e9807", null ],
+    [ "advanceGLPolyValue", "_pro_s_h_a_d_e__maths_8hpp.html#a07b210054215a4b80387606e94bf674c", null ],
     [ "arrayMedianAndIQR", "_pro_s_h_a_d_e__maths_8hpp.html#aa5a356017340781739a3bd66c716cfa5", null ],
-    [ "binReciprocalSpaceReflections", "_pro_s_h_a_d_e__maths_8hpp.html#aa2702798938d50ec2a55e46cbc31333e", null ],
+    [ "binReciprocalSpaceReflections", "_pro_s_h_a_d_e__maths_8hpp.html#ac8db61d55ecc0496454c2985d4e21d8b", null ],
     [ "build3x3MatrixFromDiag", "_pro_s_h_a_d_e__maths_8hpp.html#a5a65abe8c99adbd99419b9c65d25a3b2", null ],
     [ "build3x3MatrixFromXYZRotations", "_pro_s_h_a_d_e__maths_8hpp.html#a12a5f7b87baedbe1cd37ad588d3fca92", null ],
     [ "combineFourierForTranslation", "_pro_s_h_a_d_e__maths_8hpp.html#a64ba4ba55d58078eeea8b70311e4ab49", null ],
-    [ "completeLegendreSeries", "_pro_s_h_a_d_e__maths_8hpp.html#a31c91064de64aef9f8278d533f8188ad", null ],
+    [ "completeAbscissasAndWeights", "_pro_s_h_a_d_e__maths_8hpp.html#a483d8c9ae8c51ac2bf853075e6b96044", null ],
     [ "complexMatrixSVDSigmasOnly", "_pro_s_h_a_d_e__maths_8hpp.html#ab98abe6f7fac976a70b608951dbdf993", null ],
     [ "complexMultiplication", "_pro_s_h_a_d_e__maths_8hpp.html#a254fece06e1cfce122a11ddea4f71970", null ],
     [ "complexMultiplicationConjug", "_pro_s_h_a_d_e__maths_8hpp.html#a2ca5a3aedba75f52aaf707edc4e790f7", null ],
@@ -23,41 +23,44 @@ var _pro_s_h_a_d_e__maths_8hpp =
     [ "computeCrossProduct", "_pro_s_h_a_d_e__maths_8hpp.html#a2bbee3728be168eb54099ddb9bc0689a", null ],
     [ "computeDotProduct", "_pro_s_h_a_d_e__maths_8hpp.html#a2ac3b534f974de25b092e9d48d9f7dea", null ],
     [ "computeDotProduct", "_pro_s_h_a_d_e__maths_8hpp.html#a3b37ae1c35d048fd5dbff0a2cfcc4601", null ],
-    [ "computeFSC", "_pro_s_h_a_d_e__maths_8hpp.html#ab32d795fc4057093f27e5981551f5d99", null ],
+    [ "computeFSC", "_pro_s_h_a_d_e__maths_8hpp.html#aa9a8864f70989536606fb8cc5363aead", null ],
     [ "computeFSCWeightByBin", "_pro_s_h_a_d_e__maths_8hpp.html#a4915884de2c0c846d74baf77003ca29c", null ],
     [ "computeGaussian", "_pro_s_h_a_d_e__maths_8hpp.html#ad30fc4ec4f4239e4860270955a28fdcc", null ],
     [ "computeTheFValue", "_pro_s_h_a_d_e__maths_8hpp.html#a4d8ecf33b4e65b2404ce064b054845b1", null ],
     [ "computeTrFunDerivatives", "_pro_s_h_a_d_e__maths_8hpp.html#a39cf8a79d316806c1140c6cd7a9b49ca", null ],
     [ "computeTrFunStep", "_pro_s_h_a_d_e__maths_8hpp.html#a7fa32a45083a0154c5f0b039bae9ab39", null ],
+    [ "cutArrayToResolution", "_pro_s_h_a_d_e__maths_8hpp.html#ac24635e94df5eb2a7ee792e02ac49a84", null ],
+    [ "cutIndicesToResolution", "_pro_s_h_a_d_e__maths_8hpp.html#a8d2c10e26fe26ca95c849d8570a8ec2a", null ],
     [ "dgeev_", "_pro_s_h_a_d_e__maths_8hpp.html#aff2cf3abcfbf8f70b24b369ee3392b12", null ],
     [ "dgesdd_", "_pro_s_h_a_d_e__maths_8hpp.html#aa54f5391ab62bf98a331d79d6114c346", null ],
-    [ "evaluateGLSeries", "_pro_s_h_a_d_e__maths_8hpp.html#a7e69b64278319ae1a1268d1a55545675", null ],
+    [ "evaluateGLPolynomial", "_pro_s_h_a_d_e__maths_8hpp.html#a15751b9aa49196d1052e7604ef74d01c", null ],
     [ "findAllPrimes", "_pro_s_h_a_d_e__maths_8hpp.html#a2454c19169bb38d616e52b99f1dc4495", null ],
     [ "findHighestValueInMap", "_pro_s_h_a_d_e__maths_8hpp.html#a7caf87603d759cb0de1b0bd834ae8f6d", null ],
     [ "findPeaks1D", "_pro_s_h_a_d_e__maths_8hpp.html#ab02121573c2176b879404bad104b33e4", null ],
     [ "findRotMatMatchingVectors", "_pro_s_h_a_d_e__maths_8hpp.html#a2b17617f8b3c42c5199948828cd1a57b", null ],
-    [ "findTopGroupSmooth", "_pro_s_h_a_d_e__maths_8hpp.html#a26fa82e82a6a4af696cfae0581785446", null ],
-    [ "findTopGroupSmooth", "_pro_s_h_a_d_e__maths_8hpp.html#a4c9eee80c21be71c62220ea338c0a54b", null ],
+    [ "findTopGroupSmooth", "_pro_s_h_a_d_e__maths_8hpp.html#adcf5cec480f2fa3deae1ba709168f8ff", null ],
+    [ "findTopGroupSmooth", "_pro_s_h_a_d_e__maths_8hpp.html#a8244eafa79d0def2d6b7678d32c5e2ee", null ],
     [ "findVectorFromThreeVAndThreeD", "_pro_s_h_a_d_e__maths_8hpp.html#ae9f376bb341b192fff008b9b4ef5c603", null ],
     [ "findVectorFromTwoVAndTwoD", "_pro_s_h_a_d_e__maths_8hpp.html#a45fbcfaeaabf9bae2fbd7d46a5fb4bc7", null ],
     [ "gaussLegendreIntegration", "_pro_s_h_a_d_e__maths_8hpp.html#a3d4604176a61820f5fcb95e372861c1d", null ],
     [ "gaussLegendreIntegrationReal", "_pro_s_h_a_d_e__maths_8hpp.html#a62133f51851217e3cb28dff2f520d192", null ],
     [ "getAxisAngleFromRotationMatrix", "_pro_s_h_a_d_e__maths_8hpp.html#aad5409074bece14a244fad191524a687", null ],
     [ "getAxisAngleFromRotationMatrix", "_pro_s_h_a_d_e__maths_8hpp.html#aec42a4efcef6dffaf047acde57acea99", null ],
-    [ "getEulerZXZFromAngleAxis", "_pro_s_h_a_d_e__maths_8hpp.html#a91d9c1e755e7bf89e6de8f79fd4936df", null ],
-    [ "getEulerZXZFromRotMatrix", "_pro_s_h_a_d_e__maths_8hpp.html#ae6f6afcef5b90ca77d7d6a9e91824e28", null ],
-    [ "getEulerZXZFromSOFTPosition", "_pro_s_h_a_d_e__maths_8hpp.html#acf6c5376edac98e54ef0e418cd05d706", null ],
-    [ "getGLFirstEvenRoot", "_pro_s_h_a_d_e__maths_8hpp.html#a1823adaca871244e42347ecb8ed834a2", null ],
+    [ "getEulerZYZFromAngleAxis", "_pro_s_h_a_d_e__maths_8hpp.html#a82ebdef9456bc4d6efa7dc0e69d89cf6", null ],
+    [ "getEulerZYZFromRotMatrix", "_pro_s_h_a_d_e__maths_8hpp.html#aedc0151f1586561eaf298d6697cae7c0", null ],
+    [ "getEulerZYZFromSOFTPosition", "_pro_s_h_a_d_e__maths_8hpp.html#a7c4df27d692ba004ff73a3f80287b5b6", null ],
+    [ "getGLFirstRealRoot", "_pro_s_h_a_d_e__maths_8hpp.html#a3189a6f44294a59bbae9e8795ce5c8e3", null ],
     [ "getGLPolyAtZero", "_pro_s_h_a_d_e__maths_8hpp.html#affab74b910cda2ee3faa461740a7a432", null ],
-    [ "getLegendreAbscAndWeights", "_pro_s_h_a_d_e__maths_8hpp.html#a6e2f7de1bba288270ce2cc772d28d065", null ],
+    [ "getLegendreAbscAndWeights", "_pro_s_h_a_d_e__maths_8hpp.html#a51e2b40392901a544d6f8786be8a9de8", null ],
     [ "getResolutionOfReflection", "_pro_s_h_a_d_e__maths_8hpp.html#a51be603bcedf202a40a490aa3fc8d45a", null ],
     [ "getRotationMatrixFromAngleAxis", "_pro_s_h_a_d_e__maths_8hpp.html#a39eafef902a49cc0816a2ed675c14a49", null ],
     [ "getRotationMatrixFromAngleAxis", "_pro_s_h_a_d_e__maths_8hpp.html#a0860239f5ba95153f2b12d40a5742936", null ],
-    [ "getRotationMatrixFromEulerZXZAngles", "_pro_s_h_a_d_e__maths_8hpp.html#abd9fe573a48f499dd7d1df4f779222f1", null ],
-    [ "getRotationMatrixFromEulerZXZAngles", "_pro_s_h_a_d_e__maths_8hpp.html#adccd7507561d95a44315b0eebe285272", null ],
-    [ "getSOFTPositionFromEulerZXZ", "_pro_s_h_a_d_e__maths_8hpp.html#adea245a9b2b305f970be1ed62b141cce", null ],
+    [ "getRotationMatrixFromEulerZYZAngles", "_pro_s_h_a_d_e__maths_8hpp.html#aa641924ffebe607a335350a07a14ce11", null ],
+    [ "getRotationMatrixFromEulerZYZAngles", "_pro_s_h_a_d_e__maths_8hpp.html#a4550d6831b0d3e28f3eed60902705450", null ],
+    [ "getSOFTPositionFromEulerZYZ", "_pro_s_h_a_d_e__maths_8hpp.html#a6c3bf506ba66e4536b7cb34138fe61cd", null ],
     [ "isAxisUnique", "_pro_s_h_a_d_e__maths_8hpp.html#a2380a3710f7dbe672519c3adda30f7cd", null ],
     [ "isAxisUnique", "_pro_s_h_a_d_e__maths_8hpp.html#a49f093fbdd34498d27a4d8998b620c91", null ],
+    [ "isPrime", "_pro_s_h_a_d_e__maths_8hpp.html#accdd194fd4d4a4415d0bb8711e300add", null ],
     [ "multiplyGroupElementMatrices", "_pro_s_h_a_d_e__maths_8hpp.html#a18222a942e5fff8eecd15f1235c609e1", null ],
     [ "multiplyTwoSquareMatrices", "_pro_s_h_a_d_e__maths_8hpp.html#a10bbc3e6e75c26cfbe90664dd2a7d151", null ],
     [ "normalDistributionValue", "_pro_s_h_a_d_e__maths_8hpp.html#a01087ea3e0db56758d1771618e2e4a45", null ],
@@ -69,12 +72,18 @@ var _pro_s_h_a_d_e__maths_8hpp =
     [ "prepareBiCubicInterpolatorsPlusPlus", "_pro_s_h_a_d_e__maths_8hpp.html#ac3b355465dd2244b51e579dcb8669b3a", null ],
     [ "primeFactorsDecomp", "_pro_s_h_a_d_e__maths_8hpp.html#a6359dd366cdd986f5ad155bff8235a8e", null ],
     [ "realMatrixSVDUandVOnly", "_pro_s_h_a_d_e__maths_8hpp.html#a689d9fe55f079cb37a7446103f6103ba", null ],
+    [ "rotationMatrixSimilarity", "_pro_s_h_a_d_e__maths_8hpp.html#a564e6272f205c6c44f734c6200ca520c", null ],
     [ "rotationMatrixSimilarity", "_pro_s_h_a_d_e__maths_8hpp.html#a4348a7a36275c9cea20b5c27093c9b7e", null ],
-    [ "smoothen1D", "_pro_s_h_a_d_e__maths_8hpp.html#aa2da3e6dc4d41b8f09b47982fe74b3ea", null ],
+    [ "rotationMatrixSimilarityValue", "_pro_s_h_a_d_e__maths_8hpp.html#a096ed4f79375598802116f2473dd218c", null ],
+    [ "rotationMatrixSimilarityValue", "_pro_s_h_a_d_e__maths_8hpp.html#af7b74d6e9732d99ea62a5212bac9527f", null ],
+    [ "smoothen1D", "_pro_s_h_a_d_e__maths_8hpp.html#a83ad1d4fcd0902147fc6f87e09c08ca9", null ],
     [ "transpose3x3MatrixInPlace", "_pro_s_h_a_d_e__maths_8hpp.html#ac6c48ee69a642f279354789f09b02296", null ],
+    [ "transpose3x3MatrixInPlace", "_pro_s_h_a_d_e__maths_8hpp.html#a4e18da715a7b9e6d84f6eda66b40e4e5", null ],
     [ "vectorMeanAndSD", "_pro_s_h_a_d_e__maths_8hpp.html#a8a7c6330e101fb6d729aaf6f545db9c8", null ],
     [ "vectorMedianAndIQR", "_pro_s_h_a_d_e__maths_8hpp.html#af185ca14eb5d82fb126092767746e00a", null ],
     [ "vectorOrientationSimilarity", "_pro_s_h_a_d_e__maths_8hpp.html#a2b2f67cba1eea57f19fdaf062db74fde", null ],
     [ "vectorOrientationSimilaritySameDirection", "_pro_s_h_a_d_e__maths_8hpp.html#a79e789452e327bb07a53c5358f4d3eb0", null ],
+    [ "whichAxisUnique", "_pro_s_h_a_d_e__maths_8hpp.html#a5f74449c947cbf139f9700bc9f2e7119", null ],
+    [ "whichAxisUnique", "_pro_s_h_a_d_e__maths_8hpp.html#aa99cf5a693118bf979c235d9e7ae05d4", null ],
     [ "zgesdd_", "_pro_s_h_a_d_e__maths_8hpp.html#a0cbbac6da7eaf965ee286850344c51e7", null ]
 ];
\ No newline at end of file
