@@ -4,14 +4,14 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "ProSHADE_data", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7afb32f0574cb707876c4502680dfd80", null ],
     [ "~ProSHADE_data", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a485495727d37abd66295bab95d368438", null ],
     [ "addExtraSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7a402c710af1af5fabf7505848dad047", null ],
-    [ "allocateEMatrices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4e78c033b2c8c038038887105d67b115", null ],
+    [ "allocateEMatrices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4e17d71d4b431276e6cbc83b92daf548", null ],
     [ "allocateRotatedSHMemory", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa978d98f77a64fb16862b67a0de634be", null ],
     [ "allocateRRPMemory", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4f8698493efda1aa3e057c266d5c697b", null ],
     [ "allocateSO3CoeffsSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abc4a61da919ae37b0a03d23df2461224", null ],
     [ "allocateWignerMatricesSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aea644c87703e005507e187aa0ffa64b7", null ],
     [ "centreMapOnCOM", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a80ff45ef40549fb6a1d80b70865fc807", null ],
-    [ "computeFSC", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7c9b62338517f1da1693b1073ebc9389", null ],
-    [ "computeFSC", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a42419398083b05da19ebfb3cfa5cdc34", null ],
+    [ "computeFSC", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a657a6945e6ec94ca4dd05390a20d7c25", null ],
+    [ "computeFSC", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aada846a10b08d1c4f2cf40b013478546", null ],
     [ "computeRotatedSH", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad39f33c52f6d4f0db8e0d63ed0c9a2f3", null ],
     [ "computeRotationFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac7cb89ed871668c57a3b5dc953c20482", null ],
     [ "computeRRPMatrices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a6db2dcf87a6f763909ab08201e8de550", null ],
@@ -19,22 +19,27 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "computeTranslationMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a767640acbf4999201ce9ea86d76ff6a1", null ],
     [ "convertRotationFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad96cd7a72fc56e7d97cfeff1086faad9", null ],
     [ "createNewMapFromBounds", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a3349a7f6ffecc3ffd4e09192eb919248", null ],
+    [ "decidePolyFromList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aead32eba9ef4daae0875ce44337d8aa7", null ],
     [ "deepCopyMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac3fbad5b8628112ace798950e6068bd4", null ],
-    [ "detectSymmetryFromAngleAxisSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abcf770f9177a4d2f1a94a3adb20bf790", null ],
+    [ "detectSymmetryFromAngleAxisSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a260e8a1deaa2557e493369550c56b46e", null ],
+    [ "determineRecommendedSymmetry", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae8c36e9201119771b3ebdbc5a6cb05f9", null ],
     [ "figureIndexStartStop", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a476092aa08dff20d64a895e7b2227b2e", null ],
     [ "findMapCOM", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac07955296611dd411cf5ed87ced90571", null ],
     [ "findRequestedCSymmetryFromAngleAxis", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a2714fcb2c08b224ccf09d64322bd2ab2", null ],
-    [ "getAllGroupElements", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae2f2469c7d252c5e87d7bf9976b9b796", null ],
+    [ "getAllGroupElements", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abb67fc1576d9375f691caf224b12a15d", null ],
     [ "getAllGroupElements", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afc06f274535401086eefad02fcc8ac10", null ],
     [ "getAnySphereRadius", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a23620b34a604aca7db4d8b21f6d2d09a", null ],
     [ "getBestRotationMapPeaksEulerAngles", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a129f0b665c31fe2d6c7a03f1ba9997de", null ],
     [ "getBestTranslationMapPeaksAngstrom", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a53412a6bef001a7be8fd98ceaa8a8648", null ],
-    [ "getComparisonBand", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a6cc2b8e179a137adda234e0ba0f9d27b", null ],
+    [ "getCyclicAxes", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a3704cb64f672f4edc5a7f1de2642fc44", null ],
+    [ "getCyclicAxesCopy", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a72c9b87ed71a25d77cbba9ac39b8dcb6", null ],
     [ "getCyclicSymmetriesListFromAngleAxis", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afa3b1a8ef870a606035102b5dcf1ce44", null ],
-    [ "getDihedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a1fdc5b9df47ff8de3a5f2f6e6ce233a5", null ],
+    [ "getDihedralAxes", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa8f4456b4b59904f25427aacdff76da6", null ],
+    [ "getDihedralAxesCopy", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a113930ccaa574500c54e07a666fcd9d4", null ],
+    [ "getDihedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aaa9b27bcff97199def7de1f222273d67", null ],
+    [ "getEMatDim", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a3c5df08a778ff490e9036acc24d617f4", null ],
     [ "getEMatrixByBand", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a94a73f81ba80621f5f52173e91bb47f7", null ],
     [ "getEMatrixValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ab053362f9dc5422244ccfbafd9f00ff8", null ],
-    [ "getIcosahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad46b5c9a39df4faa45cc53d31aab43db", null ],
     [ "getImagEMatrixValuesForLM", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9b08a8b6f9569c06cd183c924e6e80de", null ],
     [ "getImagRotFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9b063d1ca2ebed239029bad6250cf376", null ],
     [ "getImagSO3Coeffs", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4b76352faa0915b1fef943fe139de5a6", null ],
@@ -48,19 +53,20 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "getMaxBand", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a152b43815a3d3debd4b60751d9c8afdd", null ],
     [ "getMaxSpheres", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a2245b15f279de574406204156089e5ef", null ],
     [ "getNoRecommendedSymmetryAxes", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad1fdcd9bdebc2900748821c5b3cb53cc", null ],
-    [ "getOctahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a14c4d6044c5174afa8a0984025c45436", null ],
+    [ "getNoRecommendedSymmetryAxes", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#acdd0102be8a0c217b4a82f2fa01e7ddf", null ],
     [ "getOverlayRotationFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad409e4556676857224d1f5e00e5b7911", null ],
-    [ "getPredictedIcosahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad9a02d8d68aac021572b764651aad0f1", null ],
-    [ "getPredictedOctahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae97b54a34689c1dceae47a5e8e94bbb0", null ],
-    [ "getPredictedTetrahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a931aa4c10c426c3b8041bd4e838b0678", null ],
+    [ "getPredictedIcosahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aac99d41a1df8c7c5bc6af8c1e0cbe600", null ],
+    [ "getPredictedOctahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abc745f8d936dd1083a3fa81b25d1b6df", null ],
+    [ "getPredictedTetrahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a3f5d42e9fd42e8817857ab8446cd0bdc", null ],
     [ "getRealEMatrixValuesForLM", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa757f9d32ebe20435661599652fd30fa", null ],
     [ "getRealRotFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a8bc5fbad1079d42bfa73913a9e2df619", null ],
     [ "getRealSO3Coeffs", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a30eac0ab5b69c1b7190d6e56571ba8b8", null ],
     [ "getRealSphHarmValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a5c0df68cd21b4f56abd1008065ca3573", null ],
     [ "getRealTranslationFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a94cce09895dc9f41d4b9a429ccf638e8", null ],
     [ "getReBoxBoundaries", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac0dc9f3ed79cc98719e6b727bb8bb982", null ],
-    [ "getRecommendedSymmetryFold", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a8e1bd5bd5a3fd12691a1d83735c13250", null ],
-    [ "getRecommendedSymmetryType", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad5add825ce8d5e5d9f598f6912f07aff", null ],
+    [ "getRecommendedSymmetryFold", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a2727d8af3b72decb0b5feb205d110821", null ],
+    [ "getRecommendedSymmetryType", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a2da46f9206150a069bab3ec7800fd7f4", null ],
+    [ "getRecommendedSymmetryValues", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a3fb17c54fd3d0f66c7d269e3607a1f35", null ],
     [ "getRotMatrixFromRotFunInds", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a688bac56d3c483bd99c0ff7d63cf7602", null ],
     [ "getRRPValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afa35ae5ccd9d4b22bcc028f609cd1c3e", null ],
     [ "getShellBandwidth", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a898b48c1135e7a37f64f55e2367f0391", null ],
@@ -68,7 +74,6 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "getSpherePositions", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a188b648a0ad28b598d682ca14f288dc4", null ],
     [ "getSpherePosValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a38d47eb11eafa106c65867ceec62a3fc", null ],
     [ "getSymmetryAxis", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a0662f17e733fb6c1a16f04b273f8b7a5", null ],
-    [ "getTetrahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a85bfab9b1babe0b35e6d81f525ead29b", null ],
     [ "getTranslationFnPointer", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae27a3e92905ca9d5f9a32c4eaacc64ae", null ],
     [ "getWignerMatrixValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a5999f7181bd3509454966f8271ac39d6", null ],
     [ "getXAxisOrigin", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a8a1405b3974697f41c4a73da0cb52a32", null ],
@@ -93,25 +98,25 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "maskMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a0122be830893f5d82bab742be54d1ee7", null ],
     [ "normaliseEMatrixValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aceb19c915cebcef22c085cc6619cc472", null ],
     [ "normaliseMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a255bdb77824ce0fddc2454d5823219e1", null ],
-    [ "prepareFSCFourierMemory", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#acf2c2c9634a9e641270f8889624c3752", null ],
+    [ "prepareFSCFourierMemory", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a582ab753eae5104d9a318f3c66a691d3", null ],
     [ "processInternalMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afcb4202e9ffea1b99c59f73faf06d899", null ],
-    [ "readInGemmi", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#af8dcc353f075b824d2f3479f487c8bd0", null ],
+    [ "readInGemmi", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a0a8aa0e88726d2f419daf6c6dd46c68b", null ],
     [ "readInMAP", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aae85fef5742e6c6c9ef7bda2ff0f7d23", null ],
     [ "readInPDB", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abd1c1b3588308f775da5c8aeba3f3e78", null ],
-    [ "readInStructure", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a341ab1de3f949e1e4688110ed641ae13", null ],
+    [ "readInStructure", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9dd0fe033bd3afa97e2b486fccfece8c", null ],
     [ "readInStructure", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aab12fb2b416250b81dd69d2e86313b59", null ],
     [ "removePhaseInormation", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a5919acc2f26efcf373db47ed96eadc38", null ],
+    [ "reportCurrentSymmetryResults", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad6fedc2b76be577c0093962352addbdd", null ],
     [ "reportOverlayResults", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a43e3cad6f93a32f92194f76f0ec76a32", null ],
     [ "reportSymmetryResults", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abea2d62360b17cddca155816d3e485e8", null ],
+    [ "reportSymmetryResultsList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aefb2868c74f06af680b9472fb48b0fb3", null ],
     [ "reSampleMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ab573ea90a16991a06a77c5343328b060", null ],
+    [ "rotateFourierCoeffs", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7ac8d81b49137da75c34c1c2c213cb3e", null ],
     [ "rotateMapRealSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a22caf254dfc11e52890f79a161493e6e", null ],
     [ "rotateMapRealSpaceInPlace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac626ea4513155170cff98fd18e6f3b09", null ],
     [ "rotateMapReciprocalSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa12ba3d9d61e240ec2d91d924e6cb0d3", null ],
-    [ "saveDetectedSymmetries", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a0b0608e80f20087b24cc9498767f0894", null ],
-    [ "saveRecommendedSymmetry", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad9b0fec5092eed1ab485443c15289e14", null ],
-    [ "saveRequestedSymmetryC", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a599a8fa1d6d780a45a2d772413bc778e", null ],
-    [ "saveRequestedSymmetryD", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa200af7e84ec7a17ecfd54a45a8ffafe", null ],
-    [ "setEMatrixValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aca5af5c8c3b18275e65ae4ebacd9877c", null ],
+    [ "saveRequestedSymmetryD", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4dfc76e0f035daf8c610a883d83e0186", null ],
+    [ "setEMatrixValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a3a413c84a8a9b667153cfa70b96da8ef", null ],
     [ "setIntegrationWeight", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a3e7b1d5d4164ea7a6fda53c57ac979f4", null ],
     [ "setIntegrationWeightCumul", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a737ee01d968fef7ae1094847a0271033", null ],
     [ "setPDBMapValues", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a30edd2928e423198704adb955989960b", null ],
@@ -131,9 +136,12 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "aAngle", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa75beee618649d6fd9dc850a5a66a551", null ],
     [ "bAngle", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9dbcec9f32eb76625d7aa59d8c2701d9", null ],
     [ "cAngle", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a8e2f99f00dd05198b508633cf7f6f080", null ],
+    [ "cyclicSymmetries", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a79d8098f503dde4b4d6c308d39313f37", null ],
+    [ "dihedralSymmetries", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a8aaa615e0e6b7922d92d958ac7989aa1", null ],
     [ "eMatrices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a82b2d8f8c05da2eccb5561e6455b4d44", null ],
     [ "fileName", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae9b0d5959b0f461b3b89ffeb059400fa", null ],
     [ "fileType", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4052e498b4650f62bfe5ff37ed959292", null ],
+    [ "icosahedralSymmetries", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a38b1c1f2c99ae69ae8e12b396cb2615a", null ],
     [ "inputOrder", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a99ab4a34f3a42c17f923ef131c64b4a7", null ],
     [ "integrationWeight", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a5d266289b137b48132f1456fd8fc43ea", null ],
     [ "internalMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a8aa6fbd67df9911e886f9001a0ef8bc2", null ],
@@ -144,9 +152,10 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "mapMovFromsChangeX", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7861a96d94b8f7a8eb2946729c330863", null ],
     [ "mapMovFromsChangeY", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a1658311301e365cf17721e864b829c28", null ],
     [ "mapMovFromsChangeZ", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a682749f30d2fd19842d96e9b870d76ab", null ],
-    [ "maxCompBand", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a99ed9b0a765739d89104eca2c1875dd4", null ],
+    [ "maxEMatDim", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ab3c7746444b58b52915aff45956655f7", null ],
     [ "maxShellBand", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a367d0cd13e3d7a2648488980220ca69b", null ],
     [ "noSpheres", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a411b398b06557387320b56c6b8233fc4", null ],
+    [ "octahedralSymmetries", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aeea225fecb6b3aaceeb61e92454693ec", null ],
     [ "originalMapXCom", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a2a3fdf194eca61b1ccfa5bdd2f586e0b", null ],
     [ "originalMapYCom", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a64323b4117a11f0971cb0d24ec95c64c", null ],
     [ "originalMapZCom", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ac00197ab71e3353cb2884be0e51d6cd3", null ],
@@ -156,6 +165,9 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "originalPdbTransX", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a9548e8ff07c6a74bbe2353f647fb6a79", null ],
     [ "originalPdbTransY", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a5241ee8b8b9d9915e1ef92e3edab202d", null ],
     [ "originalPdbTransZ", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aee571cb10ce61ab11680b1ebd5e23eb7", null ],
+    [ "recommendedSymmetryFold", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a0418069ac20c0f7b9817d16ec7647cb4", null ],
+    [ "recommendedSymmetryType", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abe89ec0a37f257c6f52d61df0d5a7014", null ],
+    [ "recommendedSymmetryValues", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a94b8ad8874b1b2e95020c2f7d8d9d528", null ],
     [ "rotSphericalHarmonics", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a94b04108aa1a9406eb3c5eb61749140b", null ],
     [ "rrpMatrices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#af8b72cbc56a4f72d0557e01a8101d435", null ],
     [ "so3Coeffs", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad5416490eb3eba7539d08a5b324fbadb", null ],
@@ -164,6 +176,7 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "spherePos", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a31b57e51f48e58828883b04b612dcf55", null ],
     [ "spheres", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa414664dde18320cc52075640590d51d", null ],
     [ "sphericalHarmonics", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a5f934f331c4d3bc7c0a6f63486b2f90e", null ],
+    [ "tetrahedralSymmetries", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae223c2a373091526e0d9fd770c977757", null ],
     [ "translationMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a37f26ac4bc76e4f4c5da77dd0eace56e", null ],
     [ "wignerMatrices", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a618fc0fc9ca71ec70500c99c7e6231f4", null ],
     [ "xAxisOrder", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a603841095e16abd0492dfc6db052fda7", null ],
