@@ -4,5 +4,7 @@ var dir_5c0d64f70903e893b1efe571a4b8de29 =
     [ "pyProSHADE_bindings.cpp", "py_pro_s_h_a_d_e__bindings_8cpp.html", "py_pro_s_h_a_d_e__bindings_8cpp" ],
     [ "pyProSHADE_data.cpp", "py_pro_s_h_a_d_e__data_8cpp.html", "py_pro_s_h_a_d_e__data_8cpp" ],
     [ "pyProSHADE_distances.cpp", "py_pro_s_h_a_d_e__distances_8cpp.html", "py_pro_s_h_a_d_e__distances_8cpp" ],
-    [ "pyProSHADE_maths.cpp", "py_pro_s_h_a_d_e__maths_8cpp.html", "py_pro_s_h_a_d_e__maths_8cpp" ]
+    [ "pyProSHADE_mapManip.cpp", "py_pro_s_h_a_d_e__map_manip_8cpp.html", "py_pro_s_h_a_d_e__map_manip_8cpp" ],
+    [ "pyProSHADE_maths.cpp", "py_pro_s_h_a_d_e__maths_8cpp.html", "py_pro_s_h_a_d_e__maths_8cpp" ],
+    [ "pyProSHADE_symmetry.cpp", "py_pro_s_h_a_d_e__symmetry_8cpp.html", "py_pro_s_h_a_d_e__symmetry_8cpp" ]
 ];
\ No newline at end of file
