@@ -16,8 +16,8 @@
 
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.6.5
-    \date      JUN 2022
+    \version   0.7.6.6
+    \date      JUL 2022
 */
 
 //==================================================== ProSHADE
@@ -106,21 +106,21 @@ int main ( int argc, char **argv )
     
     //================================================ Expected output
 //  Detected symmetry C of fold 12. The symmetry axes are:
-//   ... FOLD: 12 | XYZ: 0 ; 0 ; 1 | Angle: 0.523599 | Peak: 0.994557 | Average FSC: 0.992264
+//   ... FOLD: 12 | XYZ: 0 ; 0 ; 1 | Angle: 0.523599 | Peak: 0.996047 | Average FSC: 0.992328
 
     //================================================ Get list of all detected cyclic symmetries
     std::vector < std::vector< proshade_double > > allCs = runProshade->getAllCSyms ( );
     std::cout << "Found a total of " << allCs.size() << " cyclic symmetries." << std::endl;
     
     //================================================ Expected output
-//  Found a total of 22 cyclic symmetries.
+//  Found a total of 5 cyclic symmetries.
     
     //================================================ Find the internal map processing COM shift
     std::vector< proshade_double > comMove            = runProshade->getMapCOMProcessChange ( );
     std::cout << "Internal map processing shifted the map COM by: [" << comMove.at(0) << " , " << comMove.at(1) << " , " << comMove.at(2) << "]." << std::endl;
     
     //================================================ Expected output
-//  Internal map processing shifted the map COM by: [-0.0347284 , -0.0296968 , 13.0487].
+//  Internal map processing shifted the map COM by: [-0.00527658 , -0.00468209 , 11.8497].
     
     //================================================ Release the settings and runProshade objects
     delete runProshade;
